@@ -9,7 +9,7 @@ from urllib.parse import urlparse
 from aiohttp import web
 
 from .tornado import open_webbrowser_on_server_started
-from .utils import make_applications
+from .utils import make_applications, render_page, cdn_validation
 from ..session import CoroutineBasedSession, ThreadBasedSession, register_session_implement_for_target, Session
 from ..session.base import get_session_info_from_headers
 from ..utils import get_free_port, STATIC_PATH, iscoroutinefunction, isgeneratorfunction
@@ -37,12 +37,12 @@ def _is_same_site(origin, host):
     return origin == host
 
 
-def _webio_handler(applications, websocket_settings, check_origin_func=_is_same_site):
-    """获取用于Tornado进行整合的RequestHandle类
-
-    :param dict applications: 任务名->任务函数 的映射
+def _webio_handler(applications, cdn, websocket_settings, check_origin_func=_is_same_site):
+    """
+    :param dict applications: dict of `name -> task function`
+    :param bool/str cdn: Whether to load front-end static resources from CDN
     :param callable check_origin_func: check_origin_func(origin, handler) -> bool
-    :return: Tornado RequestHandle类
+    :return: aiohttp Request Handler
     """
     ioloop = asyncio.get_event_loop()
 
@@ -51,6 +51,16 @@ def _webio_handler(applications, websocket_settings, check_origin_func=_is_same_
         if origin and not check_origin_func(origin=origin, host=request.host):
             return web.Response(status=403, text="Cross origin websockets not allowed")
 
+        if request.headers.get("Upgrade", "").lower() != "websocket":
+            # Backward compatible
+            if request.query.getone('test', ''):
+                return web.Response(text="")
+
+            app_name = request.query.getone('app', 'index')
+            app = applications.get(app_name) or applications['index']
+            html = render_page(app, protocol='ws', cdn=cdn)
+            return web.Response(body=html, content_type='text/html')
+
         ws = web.WebSocketResponse(**websocket_settings)
         await ws.prepare(request)
 
@@ -93,7 +103,8 @@ def _webio_handler(applications, websocket_settings, check_origin_func=_is_same_
                 pass
             elif msg.type == web.WSMsgType.close:
                 if not close_from_session_tag:
-                    session.close()
+                    # close session because client disconnected to server
+                    session.close(nonblock=True)
                     logger.debug("WebSocket closed from client")
 
         return ws
@@ -101,16 +112,11 @@ def _webio_handler(applications, websocket_settings, check_origin_func=_is_same_
     return wshandle
 
 
-def webio_handler(applications, allowed_origins=None, check_origin=None, websocket_settings=None):
-    """获取在aiohttp中运行PyWebIO任务函数的 `Request Handle <https://docs.aiohttp.org/en/stable/web_quickstart.html#aiohttp-web-handler>`_ 协程。
-    Request Handle基于WebSocket协议与浏览器进行通讯。
+def webio_handler(applications, cdn=True, allowed_origins=None, check_origin=None, websocket_settings=None):
+    """Get the `Request Handler <https://docs.aiohttp.org/en/stable/web_quickstart.html#aiohttp-web-handler>`_ coroutine for running PyWebIO applications in aiohttp.
+    The handler communicates with the browser by WebSocket protocol.
 
-    :param list/dict/callable applications: PyWebIO应用。
-    :param list allowed_origins: 除当前域名外，服务器还允许的请求的来源列表。
-    :param callable check_origin: 请求来源检查函数。
-    :param dict websocket_settings: 创建 aiohttp WebSocketResponse 时使用的参数。见 https://docs.aiohttp.org/en/stable/web_reference.html#websocketresponse
-
-    关于 ``applications`` 、 ``allowed_origins`` 、 ``check_origin`` 参数的详细说明见 :func:`pywebio.platform.aiohttp.start_server` 的同名参数。
+    The arguments of ``webio_handler()`` have the same meaning as for :func:`pywebio.platform.aiohttp.start_server`
 
     :return: aiohttp Request Handler
     """
@@ -120,21 +126,24 @@ def webio_handler(applications, allowed_origins=None, check_origin=None, websock
 
     websocket_settings = websocket_settings or {}
 
+    cdn = cdn_validation(cdn, 'error')
+
     if check_origin is None:
         check_origin_func = partial(_check_origin, allowed_origins=allowed_origins or [])
     else:
         check_origin_func = lambda origin, handler: _is_same_site(origin, handler) or check_origin(origin)
 
-    return _webio_handler(applications=applications,
+    return _webio_handler(applications=applications,cdn=cdn,
                           check_origin_func=check_origin_func,
                           websocket_settings=websocket_settings)
 
 
 def static_routes(prefix='/'):
     """获取用于提供PyWebIO静态文件的aiohttp路由列表
+    Get the aiohttp routes list for PyWebIO static files hosting.
 
-    :param str prefix: 静态文件托管的URL路径，默认为根路径 ``/``
-    :return: aiohttp路由列表
+    :param str prefix: The URL path of static file hosting, the default is the root path ``/``
+    :return: aiohttp routes list
     """
 
     async def index(request):
@@ -148,31 +157,19 @@ def static_routes(prefix='/'):
 
 
 def start_server(applications, port=0, host='', debug=False,
+                 cdn=True, static_dir=None,
                  allowed_origins=None, check_origin=None,
                  auto_open_webbrowser=False,
                  websocket_settings=None,
                  **aiohttp_settings):
-    """启动一个 aiohttp server 将PyWebIO应用作为Web服务提供。
+    """Start a aiohttp server to provide the PyWebIO application as a web service.
 
-    :param list/dict/callable applications: PyWebIO应用. 格式同 :func:`pywebio.platform.tornado.start_server` 的 ``applications`` 参数
-    :param int port: 服务监听的端口。设置为 ``0`` 时，表示自动选择可用端口。
-    :param str host: 服务绑定的地址。 ``host`` 可以是IP地址或者为hostname。如果为hostname，服务会监听所有与该hostname关联的IP地址。
-        通过设置 ``host`` 为空字符串或 ``None`` 来将服务绑定到所有可用的地址上。
-    :param bool debug: 是否开启asyncio的Debug模式
-    :param list allowed_origins: 除当前域名外，服务器还允许的请求的来源列表。
-        来源包含协议、域名和端口部分，允许使用 Unix shell 风格的匹配模式(全部规则参见 `Python文档 <https://docs.python.org/zh-tw/3/library/fnmatch.html>`_ ):
+    :param dict websocket_settings: The  parameters passed to the constructor of ``aiohttp.web.WebSocketResponse``.
+       For details, please refer: https://docs.aiohttp.org/en/stable/web_reference.html#websocketresponse
+    :param aiohttp_settings: Additional keyword arguments passed to the constructor of ``aiohttp.web.Application``.
+       For details, please refer: https://docs.aiohttp.org/en/stable/web_reference.html#application
 
-        - ``*`` 为通配符
-        - ``?`` 匹配单个字符
-        - ``[seq]`` 匹配seq中的字符
-        - ``[!seq]`` 匹配不在seq中的字符
-
-        比如 ``https://*.example.com`` 、 ``*://*.example.com``
-    :param callable check_origin: 请求来源检查函数。接收请求来源(包含协议、域名和端口部分)字符串，
-        返回 ``True/False`` 。若设置了 ``check_origin`` ， ``allowed_origins`` 参数将被忽略
-    :param bool auto_open_webbrowser: 当服务启动后，是否自动打开浏览器来访问服务。（该操作需要操作系统支持）
-    :param dict websocket_settings: 创建 aiohttp WebSocketResponse 时使用的参数。见 https://docs.aiohttp.org/en/stable/web_reference.html#websocketresponse
-    :param aiohttp_settings: 需要传给 aiohttp Application 的参数。可用参数见 https://docs.aiohttp.org/en/stable/web_reference.html#application
+    The rest arguments of ``start_server()`` have the same meaning as for :func:`pywebio.platform.tornado.start_server`
     """
     kwargs = locals()
 
@@ -182,11 +179,15 @@ def start_server(applications, port=0, host='', debug=False,
     if port == 0:
         port = get_free_port()
 
-    handler = webio_handler(applications, allowed_origins=allowed_origins, check_origin=check_origin,
-                            websocket_settings=websocket_settings)
+    cdn = cdn_validation(cdn, 'warn')
+
+    handler = webio_handler(applications, cdn=cdn, allowed_origins=allowed_origins,
+                            check_origin=check_origin, websocket_settings=websocket_settings)
 
     app = web.Application(**aiohttp_settings)
-    app.router.add_routes([web.get('/io', handler)])
+    app.router.add_routes([web.get('/', handler)])
+    if static_dir is not None:
+        app.router.add_routes([web.static('/static', static_dir)])
     app.router.add_routes(static_routes())
 
     if auto_open_webbrowser:
