@@ -1,12 +1,12 @@
 import json
 import logging
+import os
 import threading
-from functools import partial
 
 from django.http import HttpResponse, HttpRequest
 
 from .httpbased import HttpContext, HttpHandler, run_event_loop
-from .utils import make_applications
+from .utils import make_applications, cdn_validation
 from ..utils import STATIC_PATH, iscoroutinefunction, isgeneratorfunction, get_free_port
 
 logger = logging.getLogger(__name__)
@@ -56,6 +56,7 @@ class DjangoHttpContext(HttpContext):
         :param content:
         :param bool json_type: content是否要序列化成json格式，并将 content-type 设置为application/json
         """
+        # self.response.content accept str and byte
         if json_type:
             self.set_header('content-type', 'application/json')
             self.response.content = json.dumps(content)
@@ -71,29 +72,23 @@ class DjangoHttpContext(HttpContext):
         return self.request.META.get('REMOTE_ADDR')
 
 
-def webio_view(applications,
+def webio_view(applications, cdn=True,
                session_expire_seconds=None,
                session_cleanup_interval=None,
                allowed_origins=None, check_origin=None):
-    """获取在django中运行PyWebIO任务的视图函数。
-    基于http请求与前端进行通讯
+    """Get the view function for running PyWebIO applications in Django.
+    The view communicates with the browser by HTTP protocol.
 
-    :param list/dict/callable applications: PyWebIO应用。
-    :param int session_expire_seconds: 会话不活跃过期时间。
-    :param int session_cleanup_interval: 会话清理间隔。
-    :param list allowed_origins: 除当前域名外，服务器还允许的请求的来源列表。
-    :param callable check_origin: 请求来源检查函数。
-
-    关于各参数的详细说明见 :func:`pywebio.platform.django.start_server` 的同名参数。
-
-    :return: Django视图函数
+    The arguments of ``webio_view()`` have the same meaning as for :func:`pywebio.platform.flask.webio_view`
     """
-    handler = HttpHandler(applications=applications,
+    cdn = cdn_validation(cdn, 'error')
+    handler = HttpHandler(applications=applications, cdn=cdn,
                           session_expire_seconds=session_expire_seconds,
                           session_cleanup_interval=session_cleanup_interval,
                           allowed_origins=allowed_origins, check_origin=check_origin)
 
     from django.views.decorators.csrf import csrf_exempt
+
     @csrf_exempt
     def view_func(request):
         context = DjangoHttpContext(request)
@@ -106,40 +101,20 @@ def webio_view(applications,
 urlpatterns = []
 
 
-def start_server(applications, port=8080, host='localhost',
+def start_server(applications, port=8080, host='', cdn=True, static_dir=None,
                  allowed_origins=None, check_origin=None,
-                 disable_asyncio=False,
-                 session_cleanup_interval=None,
                  session_expire_seconds=None,
+                 session_cleanup_interval=None,
                  debug=False, **django_options):
-    """启动一个 Django server 将PyWebIO应用作为Web服务提供。
+    """Start a Django server to provide the PyWebIO application as a web service.
 
-    :param list/dict/callable applications: PyWebIO应用. 格式同 :func:`pywebio.platform.tornado.start_server` 的 ``applications`` 参数
-    :param int port: 服务监听的端口。设置为 ``0`` 时，表示自动选择可用端口。
-    :param str host: 服务绑定的地址。 ``host`` 可以是IP地址或者为hostname。如果为hostname，服务会监听所有与该hostname关联的IP地址。
-        通过设置 ``host`` 为空字符串或 ``None`` 来将服务绑定到所有可用的地址上。
-    :param list allowed_origins: 除当前域名外，服务器还允许的请求的来源列表。
-        来源包含协议、域名和端口部分，允许使用 Unix shell 风格的匹配模式(全部规则参见 `Python文档 <https://docs.python.org/zh-tw/3/library/fnmatch.html>`_ ):
+    :param bool debug: Django debug mode.
+       See `Django doc <https://docs.djangoproject.com/en/3.0/ref/settings/#debug>`_ for more detail.
+    :param django_options: Additional settings to django server.
+       For details, please refer: https://docs.djangoproject.com/en/3.0/ref/settings/ .
+       Among them, ``DEBUG``, ``ALLOWED_HOSTS``, ``ROOT_URLCONF``, ``SECRET_KEY`` are set by PyWebIO and cannot be specified in ``django_options``.
 
-        - ``*`` 为通配符
-        - ``?`` 匹配单个字符
-        - ``[seq]`` 匹配seq中的字符
-        - ``[!seq]`` 匹配不在seq中的字符
-
-        比如 ``https://*.example.com`` 、 ``*://*.example.com``
-    :param callable check_origin: 请求来源检查函数。接收请求来源(包含协议、域名和端口部分)字符串，
-        返回 ``True/False`` 。若设置了 ``check_origin`` ， ``allowed_origins`` 参数将被忽略
-    :param bool disable_asyncio: 禁用 asyncio 函数。仅在任务函数为协程函数时有效。
-
-       .. note::  实现说明：
-           当使用Django backend时，若要在PyWebIO的会话中使用 ``asyncio`` 标准库里的协程函数，PyWebIO需要单独开启一个线程来运行 ``asyncio`` 事件循环，
-           若程序中没有使用到 ``asyncio`` 中的异步函数，可以开启此选项来避免不必要的资源浪费
-
-    :param int session_expire_seconds: 会话过期时间。若 session_expire_seconds 秒内没有收到客户端的请求，则认为会话过期。
-    :param int session_cleanup_interval: 会话清理间隔。
-    :param bool debug: 开启 Django debug mode 和一般访问日志的记录
-    :param django_options: django应用的其他设置，见 https://docs.djangoproject.com/en/3.0/ref/settings/ .
-        其中 ``DEBUG`` 、 ``ALLOWED_HOSTS`` 、 ``ROOT_URLCONF`` 、 ``SECRET_KEY`` 被PyWebIO设置，无法在 ``django_options`` 中指定
+    The rest arguments of ``start_server()`` have the same meaning as for :func:`pywebio.platform.flask.start_server`
     """
     global urlpatterns
 
@@ -148,7 +123,6 @@ def start_server(applications, port=8080, host='localhost',
     from django.urls import path
     from django.utils.crypto import get_random_string
     from django.views.static import serve
-    from django.core.management import call_command
 
     if port == 0:
         port = get_free_port()
@@ -156,6 +130,8 @@ def start_server(applications, port=8080, host='localhost',
     if not host:
         host = '0.0.0.0'
 
+    cdn = cdn_validation(cdn, 'warn')
+
     django_options.update(dict(
         DEBUG=debug,
         ALLOWED_HOSTS=["*"],  # Disable host header validation
@@ -186,7 +162,7 @@ def start_server(applications, port=8080, host='localhost',
     settings.configure(**django_options)
 
     webio_view_func = webio_view(
-        applications=applications,
+        applications=applications, cdn=cdn,
         session_expire_seconds=session_expire_seconds,
         session_cleanup_interval=session_cleanup_interval,
         allowed_origins=allowed_origins,
@@ -194,22 +170,26 @@ def start_server(applications, port=8080, host='localhost',
     )
 
     urlpatterns = [
-        path(r"io", webio_view_func),
-        path(r'', partial(serve, path='index.html'), {'document_root': STATIC_PATH}),
+        path(r"", webio_view_func),
         path(r'<path:path>', serve, {'document_root': STATIC_PATH}),
     ]
+    if static_dir is not None:
+        urlpatterns.insert(0, path(r'static/<path:path>', serve, {'document_root': static_dir}))
 
-    app = get_wsgi_application()  # load app
+    use_tornado_wsgi = os.environ.get('PYWEBIO_DJANGO_WITH_TORNADO', True)
+    if use_tornado_wsgi:
+        app = get_wsgi_application()  # load app
 
-    has_coro_target = any(iscoroutinefunction(target) or isgeneratorfunction(target) for
-                          target in make_applications(applications).values())
-    if not disable_asyncio and has_coro_target:
-        threading.Thread(target=run_event_loop, daemon=True).start()
+        import tornado.wsgi
+        container = tornado.wsgi.WSGIContainer(app)
+        http_server = tornado.httpserver.HTTPServer(container)
+        http_server.listen(port, address=host)
+        tornado.ioloop.IOLoop.current().start()
+    else:
+        from django.core.management import call_command
+        has_coro_target = any(iscoroutinefunction(target) or isgeneratorfunction(target) for
+                              target in make_applications(applications).values())
+        if has_coro_target:
+            threading.Thread(target=run_event_loop, daemon=True).start()
 
-    # call_command('runserver', '%s:%d' % (host, port))
-    # or use below code to run web app
-    import tornado.wsgi
-    container = tornado.wsgi.WSGIContainer(app)
-    http_server = tornado.httpserver.HTTPServer(container)
-    http_server.listen(port, address=host)
-    tornado.ioloop.IOLoop.current().start()
+        call_command('runserver', '%s:%d' % (host, port))
