@@ -9,11 +9,25 @@ import string
 import time
 from collections import OrderedDict
 from contextlib import closing
-from os.path import abspath, dirname
+from os.path import abspath, dirname, join, normpath
 
 project_dir = dirname(abspath(__file__))
 
-STATIC_PATH = '%s/html' % project_dir
+STATIC_PATH = join(project_dir, 'html')
+
+
+def pyinstaller_datas(cli_args=False):
+    """Return data files included in the PyWebIO to be added to pyinstaller bundle."""
+    datas = [
+        (STATIC_PATH, 'pywebio/html'),
+        (normpath(STATIC_PATH + '/../platform/tpl'), 'pywebio/platform/tpl')
+    ]
+    if cli_args:
+        args = ''
+        for item in datas:
+            args += ' --add-data %s%s%s' % (item[0], os.pathsep, item[1])
+        return args
+    return datas
 
 
 class Setter:
@@ -99,6 +113,7 @@ class ObjectDictProxy:
 
     def __getattr__(self, item):
         """访问一个不存在的属性时触发"""
+        assert not item.startswith('_'), 'object has no attribute %s' % item
         return self._dict.get(item, None)
 
     def __delattr__(self, item):
@@ -108,18 +123,18 @@ class ObjectDictProxy:
             pass
 
 
-class ObjectDict(dict):
-    """
-    Object like dict, every dict[key] can visite by dict.key
+class ReadOnlyObjectDict(ObjectDictProxy):
+    def __delitem__(self, key):
+        raise NotImplementedError
 
-    If dict[key] is `Get`, calculate it's value.
-    """
+    def __delattr__(self, item):
+        raise NotImplementedError
 
-    def __getattr__(self, name):
-        ret = self.__getitem__(name)
-        if hasattr(ret, '__get__'):
-            return ret.__get__(self, ObjectDict)
-        return ret
+    def __setitem__(self, key, item):
+        raise NotImplementedError
+
+    def __setattr__(self, key, value):
+        raise NotImplementedError
 
 
 def catch_exp_call(func, logger):
@@ -159,7 +174,7 @@ def get_function_doc(func):
     如果函数被functools.partial包装，则返回内部原始函数的文档，可以通过设置新函数的 func.__doc__ 属性来更新doc注释
     """
     partial_doc = inspect.getdoc(functools.partial)
-    if isinstance(func, functools.partial) and getattr(func, '__doc__', '') == partial_doc:
+    if isinstance(func, functools.partial) and inspect.getdoc(func) == partial_doc:
         while isinstance(func, functools.partial):
             func = func.func
     return inspect.getdoc(func) or ''
@@ -332,3 +347,24 @@ OR
     pip3 install -U https://code.aliyun.com/wang0618/pywebio/repository/archive.zip
 """.strip()
     raise RuntimeError(error_msg)
+
+
+def parse_file_size(size):
+    """Transform file size to byte
+
+    :param str/int/float size: 1, '30', '20M', '32k', '16G', '15mb'
+    :return int: in byte
+    """
+    if isinstance(size, (int, float)):
+        return int(size)
+    assert isinstance(size, str), '`size` must be int/float/str, got %s' % type(size)
+
+    size = size.lower().replace('b', '')
+
+    for idx, i in enumerate(['k', 'm', 'g', 't', 'p'], 1):
+        if i in size:
+            s = size.replace(i, '')
+            base = 2 ** (idx * 10)
+            return int(float(s) * base)
+
+    return int(size)
\ No newline at end of file
